package Dancer2::Plugin::FormValidator::Role::Profile;

use strict;
use warnings;

use Moo::Role;

requires 'profile';

1;
